<div align="center">

# PAIBox

</div>

<p align="center">
    <a href="https://github.com/PAICookers/PAIBox/blob/master/pyproject.toml">
        <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/paibox">
    </a>
    <a href="https://pypi.org/project/paibox/">
        <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/paibox?color=pink">
    </a>
    <a href="https://www.codefactor.io/repository/github/PAICookers/PAIBox">
        <img alt="CodeFactor Grade" src="https://img.shields.io/codefactor/grade/github/PAICookers/PAIBox?color=orange">
    </a>
    <a href="https://results.pre-commit.ci/latest/github/PAICookers/PAIBox/master">
        <img alt="pre-commit.ci status" src="https://results.pre-commit.ci/badge/github/PAICookers/PAIBox/master.svg">
    </a>
    <a href="https://codecov.io/gh/PAICookers/PAIBox" >
        <img src="https://codecov.io/gh/PAICookers/PAIBox/branch/master/graph/badge.svg?token=949SKVGRMC"/>
    </a>
</p>

👉 [用户使用指南](docs/Guide-of-PAIBox.md)

👉 [支持算子](docs/Support-Ops.md)

👉 [高效编写测试项目指南](docs/Guide-of-Test.md)

👉 [Changelog](./CHANGELOG.md)
